==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/profiles/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.profiles.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.profiles.servers', {
				url: '/{profileId}/servers',
				views: {
					profilesContent: {
						templateUrl: 'common/modules/table/profileServers/table.profileServers.tpl.html',
						controller: 'TableProfileServersController',
						resolve: {
							profile: function($stateParams, profileService) {
								return profileService.getProfile($stateParams.profileId);
							},
							servers: function($stateParams, serverService) {
								return serverService.getServers({ profileId: $stateParams.profileId, orderby: 'hostName' });
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-5.1.6.tar.gz: apache-trafficcontrol-5.1.6/traffic_portal/app/src/modules/private/profiles/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.profiles.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.profiles.servers', {
				url: '/{profileId}/servers',
				views: {
					profilesContent: {
						templateUrl: 'common/modules/table/profileServers/table.profileServers.tpl.html',
						controller: 'TableProfileServersController',
						resolve: {
							profile: function($stateParams, profileService) {
								return profileService.getProfile($stateParams.profileId);
							},
							servers: function(profile, $stateParams, serverService) {
								return serverService.getServers({ profileId: profile.id, orderby: 'hostName' });
							},
							filter: function(profile) {
								return {
									profile: {
										filterType: "text",
										type: "equals",
										filter: profile.name
									}
								}
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
